@@ -1,3 +1,5 @@
+( cd usr/java ; rm -rf jre )
+( cd usr/java ; ln -sf jre1.6.0 jre )
 ( cd usr/java/jre1.6.0/man ; rm -rf ja )
 ( cd usr/java/jre1.6.0/man ; ln -sf ja_JP.eucJP ja )
 ( cd usr/java/jre1.6.0/lib/i386/client ; rm -rf libjsig.so )
